@@ -245,6 +245,9 @@ image_new_template_changed (GimpContext    *context,
   if (!template->comment || !strlen (template->comment))
     comment = g_strdup (dialog->template->comment);
 
+  /*  make sure the resolution values are copied first (see bug #546924)  */
+  gimp_config_sync (G_OBJECT (template), G_OBJECT (dialog->template),
+                    GIMP_TEMPLATE_PARAM_COPY_FIRST);
   gimp_config_sync (G_OBJECT (template), G_OBJECT (dialog->template), 0);
 
   if (comment)
@@ -309,14 +312,14 @@ image_new_confirm_dialog (ImageNewDialog *data)
                     G_CALLBACK (image_new_confirm_response),
                     data);
 
-  size = gimp_memsize_to_string (data->template->initial_size);
+  size = g_format_size_for_display (data->template->initial_size);
   gimp_message_box_set_primary_text (GIMP_MESSAGE_DIALOG (dialog)->box,
                                      _("You are trying to create an image "
                                        "with a size of %s."), size);
   g_free (size);
 
   config = GIMP_GUI_CONFIG (data->context->gimp->config);
-  size = gimp_memsize_to_string (config->max_new_image_size);
+  size = g_format_size_for_display (config->max_new_image_size);
   gimp_message_box_set_text (GIMP_MESSAGE_DIALOG (dialog)->box,
                               _("An image of the chosen size will use more "
                                 "memory than what is configured as "
